# Schemas

Here you will find the specification for LCAx.
The specification is provided both as JSON Schemas and Python classes with Pydantic.

## LCAx

=== "Python"

    ```python
    {!> schemas/pydantic.py!}
    ```

=== "JSON Schema"

    ```json
    {!> schemas/lcax.schema.json!}
    ```

=== "Rust"

    ```rust
    {!> schemas/project.rs!}
    ```

=== "TypeScript"

    ```typescript
    {!> schemas/lcax.d.ts!}
    ```

=== "C#"

    ```csharp
    {!> schemas/lcax.cs!}
    ```

## Download

- [**Python**](./schemas/pydantic.py)
- [**JSON Schema**](./schemas/lcax.schema.json)
- [**Rust**](./schemas/project.rs)
- [**TypeScript**](./schemas/lcax.d.ts)
- [**C#**](./schemas/lcax.cs)